@@ -12,6 +12,12 @@ from dependence import normal
 from dependence import cgauss
 
 from shrinkage import shrink
+from shrinkage import target_a
+from shrinkage import target_b
+from shrinkage import target_c
+from shrinkage import target_d
+from shrinkage import target_e
+from shrinkage import target_f
 
 from edf import makeedf
 
